@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package XML::BindData;
-$XML::BindData::VERSION = '0.1.2';
+$XML::BindData::VERSION = '0.2.1';
 use XML::LibXML;
 
 sub bind {
@@ -11,7 +11,7 @@ sub bind {
 	my $xml = XML::LibXML->load_xml(string => $xml_string);
 	parse_node($xml->documentElement, $data);
 
-	return $xml->toStringC14N;
+	return $xml->toStringC14N(1);
 }
 
 sub parse_node {
@@ -63,6 +63,16 @@ sub parse_node {
 		}
 	}
 
+        if ( my $attr_defaults = _strip_attr( $node, 'tmpl-attr-defaults' ) ) {
+            my @attributes = map { [ split qr/:/ ] } split qr/,/,
+                $attr_defaults;
+
+            foreach (@attributes) {
+                $node->setAttribute( $_->[0], $_->[1] )
+                    unless defined $node->getAttribute( $_->[0] );
+            }
+        }
+
 	my @children = grep {
 		$_->nodeType eq XML_ELEMENT_NODE
 	} $node->childNodes;
@@ -274,6 +284,12 @@ Only show the node if bool is true-ish. Can be negated as C<tmpl-if="!bool">.
 Bind the value of 'opt1' into the attribute 'attr-name-one'. Multiple
 attributes can be assigned at a time, separated by commas.
 
+=item tmpl-attr-defaults="attr-name-one:default1,attr-name-two:default2"
+
+Bind the value of 'default1' into the attribute 'attr-name-one' if no other
+defined value is supplied. Multiple attributes can be assigned at a time,
+separated by commas.
+
 =back
 
 =head1 CONTRIBUTORS
